summaryrefslogtreecommitdiff
path: root/nuttx/arch/sh/src/sh1/sh1_serial.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-02-18 12:00:36 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-02-18 12:00:36 +0000
commit9fa3ac76e655b92daf653fb833da59fd904e9d17 (patch)
treef484915ce11a90da3859bf15bd018347f11bb4ab /nuttx/arch/sh/src/sh1/sh1_serial.c
parentf3fad3954742d93d27c75c2f5a1b9542cf82fc32 (diff)
downloadpx4-nuttx-9fa3ac76e655b92daf653fb833da59fd904e9d17.tar.gz
px4-nuttx-9fa3ac76e655b92daf653fb833da59fd904e9d17.tar.bz2
px4-nuttx-9fa3ac76e655b92daf653fb833da59fd904e9d17.zip
Add support for boards with no serial ports
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1512 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/arch/sh/src/sh1/sh1_serial.c')
-rw-r--r--nuttx/arch/sh/src/sh1/sh1_serial.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/arch/sh/src/sh1/sh1_serial.c b/nuttx/arch/sh/src/sh1/sh1_serial.c
index d6708d5fa..6991e0f32 100644
--- a/nuttx/arch/sh/src/sh1/sh1_serial.c
+++ b/nuttx/arch/sh/src/sh1/sh1_serial.c
@@ -829,16 +829,16 @@ static boolean up_txready(struct uart_dev_s *dev)
****************************************************************************/
/****************************************************************************
- * Name: up_serialinit
+ * Name: up_earlyconsoleinit
*
* Description:
* Performs the low level SCI initialization early in
* debug so that the serial console will be available
* during bootup. This must be called before up_serialinit.
*
****************************************************************************/
-void up_earlyserialinit(void)
+void up_earlyconsoleinit(void)
{
/* NOTE: All GPIO configuration for the SCIs was performed in
* up_lowsetup
@@ -862,15 +862,15 @@ void up_earlyserialinit(void)
}
/****************************************************************************
- * Name: up_serialinit
+ * Name: up_consoleinit
*
* Description:
* Register serial console and serial ports. This assumes
* that up_earlyserialinit was called previously.
*
****************************************************************************/
-void up_serialinit(void)
+void up_consoleinit(void)
{
/* Register the console */
@@ -829,16 +829,16 @@ static boolean up_txready(struct uart_dev_s *dev)
* Performs the low level SCI initialization early in
* debug so that the serial console will be available
- * during bootup. This must be called before up_serialinit.
+ * during bootup. This must be called before up_consoleinit.
*
****************************************************************************/
@@ -862,15 +862,15 @@ void up_earlyserialinit(void)
* Description:
* Register serial console and serial ports. This assumes
- * that up_earlyserialinit was called previously.
+ * that up_earlyconsoleinit was called previously.
*
****************************************************************************/